<?php

	// this file is used to display the list on the content_history page via AJAX

	$output = "";

	// get filter values if the filter form was submitted
	$filters_submitted = initialize("filters_submitted", "get", "text");
	$filter_status = initialize("filter_status", "get", "text");
	$filter_user = initialize("filter_user", "get", "integer");
	$filter_content = initialize("filter_content", "get", "text");
	$filter_text = initialize("filter_text", "get", "text");
	$filter_date_start_year = initialize("filter_date_start_year", "get", "text");
	$filter_date_start_month = initialize("filter_date_start_month", "get", "text");
	$filter_date_start_day = initialize("filter_date_start_day", "get", "text");
	$filter_date_end_year = initialize("filter_date_end_year", "get", "text");
	$filter_date_end_month = initialize("filter_date_end_month", "get", "text");
	$filter_date_end_day = initialize("filter_date_end_day", "get", "text");
	$sort = initialize("sort", "get", "text");
	$start = initialize("start", "get", "integer");
	
	// clean up the posted values if necessary
	if (is_array($filter_status)) { $filter_status = implode(",", $filter_status); }
	$filter_date_start = combine_date_elements($filter_date_start_year, $filter_date_start_month, $filter_date_start_day);
	$filter_date_end = combine_date_elements($filter_date_end_year, $filter_date_end_month, $filter_date_end_day);
	
	// compare filter values to those in the database
	prepare_filters("user", "content_history", "status,user,content,content_name,text,date_start,date_end");

	// modify the query based on the selected options
	$filter_SQL = "";
	if ($filter_status != "") { $filter_SQL .= " AND FIND_IN_SET(content.status, '$filter_status') "; }
	if ($filter_user > 0) { $filter_SQL .= " AND content.user='$filter_user' "; }
	if ($filter_content != "") {
		list($path, $field) = explode(",", $filter_content);
		$filter_SQL .= " AND path='$path' AND field='$field' ";
	}
	if ($filter_text != "") { $filter_SQL .= " AND content.content LIKE '%$filter_text%' "; }
	if ($filter_date_start > "0000-00-00") { $filter_SQL .= " AND content.date>='$filter_date_start 00:00:00' "; }
	if ($filter_date_end > "0000-00-00") { $filter_SQL .= " AND content.date<='$filter_date_end 23:59:59' "; }
	if ($sort) {
		$sort_SQL = " ORDER BY $sort ";
	} else {
		$sort_SQL = " ORDER BY date DESC ";
	}

	// get the list
	$query = "
		SELECT
			SQL_CALC_FOUND_ROWS
			content.ID,
			path,
			field,
			status.name AS status,
			user.name AS editor,
			user.email AS editor_email,
			DATE_ADD(date, INTERVAL $timezone HOUR) AS date,
			comment
		FROM content
		LEFT JOIN status ON status.ID=content.status
		LEFT JOIN user ON user.ID=content.user
		WHERE 1=1 $filter_SQL
		$sort_SQL
		LIMIT $start, ".LIST_ITEMS_PER_PAGE."
	";
	$result = db_do_query($query);
	$count = db_num_rows($result);
	
	// do a follow-up query to get the total number of matches, not counting the LIMIT
	$query_total = "SELECT FOUND_ROWS()";
	$result_total = db_do_query($query_total);
	$row_total = db_get_row($result_total, 0);
	$total = implode("", $row_total);
	
	if ($count == 0) {
		$output .= "<p class=\"feedback_negative\">There is no content that matches your current view</p>";
	} else {
		
		$row_styles = array("row_clear", "row_colored");		

		$output .= "<table cellpadding=\"3\" cellspacing=\"0\" width=\"100%\">\n";

		$output .= "<tr class=\"row_header\" valign=\"top\">\n";
		$output .= "<td class=\"heading\"><a href=\"JavaScript:sort('path, field')\">Name</a></td>\n";
		$output .= "<td class=\"heading\"><a href=\"JavaScript:sort('status.name')\">Status</a></td>\n";
		$output .= "<td class=\"heading\"><a href=\"JavaScript:sort('user.name')\">Editor</a></td>\n";
		$output .= "<td class=\"heading\"><a href=\"JavaScript:sort('date DESC')\">Date</a></td>\n";
		$output .= "<td class=\"heading\"><a href=\"JavaScript:sort('comment')\">Comment</a></td>\n";
		$output .= "<td class=\"heading\" colspan=\"2\">&nbsp;</td>\n";
		$output .= "</tr>\n";
		
		for ($i=0; $i < $count; $i++) {
			
			$this_row_style = $row_styles[$i % count($row_styles)];			

			$row = db_get_row($result, $i);
			extract($row);
			
			$name_display = "<a href=\"JavaScript:select_content('$path,$field', '$path, $field');\">$path, $field</a>";
			
			$comment_display = build_excerpt($ID, $comment, 64);
			
			$output .= "<tr class=\"$this_row_style\" valign=\"top\">\n";
			$output .= "<td class=\"body\">$name_display</td>\n";
			$output .= "<td class=\"body\">$status</td>\n";
			$output .= "<td class=\"body\"><a href=\"mailto:$editor_email\">$editor</a></td>\n";
			$output .= "<td class=\"body\">$date</td>\n";
			$output .= "<td class=\"body\">$comment_display</td>\n";
			$output .= "<td class=\"body\"><a href=\"JavaScript:view('$ID')\">View</a></td>\n";
			$output .= "<td class=\"body\"><a href=\"JavaScript:rollback('$ID')\">Rollback</a></td>\n";
			$output .= "</tr>\n";
				
		}
		
		$output .= "</table>\n";
	
		//$output .= "<p class=\"caption\">Displaying $i of ".get_row_count("content")." content paths</p>\n";
	
	}
	
	// build the pagination links
	$pagination_links = make_pagination_links($start, LIST_ITEMS_PER_PAGE, $total);
	if ($pagination_links) {
		$output .= "<p class=\"pagination\">$pagination_links</p>\n";
	}
	
	print $output;

?>
